#!/bin/sh
# Copyright (C) 2000-2012 Synology Inc. All rights reserved.
VERSION=1.0-010
PROJECTNAME="SSWatermark"
FULLNAME="Synology Evidence Integrity Authenticator"
BINNAME="EIAuthenticator"
SETUPNAME="SynologyEIAuthenticator"
TarFileName="${SETUPNAME}-${VERSION}.tar.gz"
ReadLink=/bin/readlink
OutputFolder="SynologyEIAuthenticator"
BINNAME="EIAuthenticator"
OLDNAME="SSWatermark"

YNConfirm() {
	read YN
	if [ "x$YN" = "xY" -o "x$YN" = "xy" ]; then
		return
	else
		exit 0
	fi
}

CheckIfNeedIA32Libs() {

	isUbuntuLinux=`uname -a | grep -ic "Ubuntu"`
	Arch=`uname -m`
	isIa32LibInstall=`dpkg --get-selections | grep -ic "ia32-libs[[:space:]]*install"`
	if [ "${isUbuntuLinux}" != "0" ]; then

		if [ "${Arch}" = "x86_64" -a "${isIa32LibInstall}" = "0" ]; then
			cat << EOF

Package [ia32-libs] is required to run ${FULLNAME}.
Root privilege is required to install the package.
Would you want to install package [ia32-libs] now? [Y/n]:
EOF
			read ANS
			if [ "x$ANS" = "xN" -o "x$ANS" = "xn" ]; then
				exit 0
			else
				sudo apt-get install ia32-libs
			fi
		fi
	fi
}

if [ ! -f ./${TarFileName} ]; then
	echo "File [${TarFileName}] not found."
	exit 255
fi

cat << EOF
This script will install ${FULLNAME} version ${VERSION} to your system.
Are you sure you want to continue? [y/N]
EOF
YNConfirm

CleanInstall() {
	cat << EOF

Please input the install path for ${FULLNAME},
Input empty path or [.] will install to current directory.
EOF
	read InstallPath

	if [ -z "${InstallPath}" ]; then
		InstallPath=`pwd`
	elif [ ! -d "${InstallPath}" ]; then
		mkdir -p ${InstallPath}
		if [ $? -ne 0 ]; then
			cat << EOF

Fail to create this directory [${InstallPath}]
Are you want to create by sudo? [y/N]
EOF
			YNConfirm
			sudo mkdir -p ${InstallPath}
		fi
	fi
	cat << EOF

Try to install ${FULLNAME} to [${InstallPath}/${SETUPNAME}] ...
Are you sure you want to continue? [y/N]
EOF
	YNConfirm

	CheckIfNeedIA32Libs

	tar zxvf ${TarFileName} -C "${InstallPath}"
	if [ $? -ne 0 ]; then
		cat << EOF

Fail to untar to this directory [${InstallPath}]
Are you want to create by sudo? [y/N]
EOF
		YNConfirm
		sudo tar zxvf ${TarFileName} -C "${InstallPath}"
	fi
}

CreateSymbolLink() {
	sudo rm -f /usr/local/bin/${OLDNAME}
	sudo rm -f /usr/local/bin/${BINNAME}
	sudo ln -sf ${InstallPath}/${OutputFolder}/${BINNAME} /usr/local/bin/${BINNAME}
}

TestSymbolLinkTarget() {
	RetSymbolic=0
	if [ ! -L /usr/local/bin/${BINNAME} ]; then
		RetSymbolic=1
	else
		LinkTarget=`$ReadLink /usr/local/bin/${BINNAME}`
		if [ "$LinkTarget" != "${InstallPath}/${OutputFolder}/${BINNAME}" ]; then
			RetSymbolic=1
		fi
	fi
	return ${RetSymbolic}
}

CleanInstall

cat << EOF

Now you can run ${FULLNAME} from
${InstallPath}/${OutputFolder}/${BINNAME} 
EOF

id | grep "uid=0" >/dev/null
if [ $? -eq 0 ]; then
	TestSymbolLinkTarget
	BuildSymbolic=$?

	if [ "${BuildSymbolic}" = 1 ]; then
		cat << EOF

Would you want to create a symbolic link [/usr/local/bin/${BINNAME}] 
to [${InstallPath}/${OutputFolder}]? 
[y/N]
EOF
		YNConfirm
		CreateSymbolLink
	fi
fi

	TestSymbolLinkTarget
	BuildSymbolic=$?

if [ "${BuildSymbolic}" = 1 ]; then
	cat << EOF

Or you can create a symbolic link 
[/usr/local/bin/${BINNAME}] to [${InstallPath}/${BINNAME}] by
\$ sudo ln -sf ${InstallPath}/${OutputFolder}/${BINNAME} \
/usr/local/bin/${BINNAME}
and run 
/usr/local/bin/${BINNAME}

EOF
else
	cat << EOF

Or you can run through the symbolic link [/usr/local/bin/${BINNAME}]
EOF
fi
